# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/newgenpower/news/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Newgenpower\\News\\": "packages/newgenpower/news/src",
            "Newgenpower\\News\\Seeders\\": "packages/newgenpower/news/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Newgenpower\News\Providers\NewsServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'News'  => Newgenpower\News\Facades\News::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Newgenpower\\News\\Seeders\\NewsTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Newgenpower\News\Providers\NewsServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Newgenpower\News\Providers\NewsServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Newgenpower\News\Providers\NewsServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/news/{modulename}

**User**

    http://path-to-route-folder/user/news/{modulename}

**Public**

    http://path-to-route-folder/news


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/news/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/news/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/news/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/news/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/news/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/news/{modulename}/{slug}
    METHOD: GET