<?php

namespace Newgenpower\News\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Newgenpower\News\Interfaces\NewsRepositoryInterface;
use Newgenpower\News\Repositories\Eloquent\Filters\NewsPublicFilter;
use Newgenpower\News\Repositories\Eloquent\Presenters\NewsListPresenter;

class NewsPublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        NewsRepositoryInterface $news
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('newgenpower.news.modules'), 'news', guard_url('news'));
        $this->repository = $news;
    }

    /**
     * Show news's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(NewsPublicFilter::class)
            ->setPresenter(NewsListPresenter::class)
            ->select('news.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('news::news.names'))
            ->view('news::public.news.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show news.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('news::news.name'))
            ->view('news::public.news.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
