<?php

namespace Newgenpower\News\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Newgenpower\News\Models\News;

class NewsPolicy
{

    /**
     * Determine if the given user can view the news.
     *
     * @param UserPolicyInterface $authUser
     * @param News $news
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, News $news)
    {
        if ($authUser->canDo('news.news.view') && $authUser->isAdmin()) {
            return true;
        }

        return $news->user_id == user_id() && $news->user_type == user_type();
    }

    /**
     * Determine if the given user can create a news.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('news.news.create');
    }

    /**
     * Determine if the given user can update the given news.
     *
     * @param UserPolicyInterface $authUser
     * @param News $news
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, News $news)
    {
        if ($authUser->canDo('news.news.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $news->user_id == user_id() && $news->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given news.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, News $news)
    {
        return $news->user_id == user_id() && $news->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given news.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, News $news)
    {
        if ($authUser->canDo('news.news.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given news.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, News $news)
    {
        if ($authUser->canDo('news.news.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
